@@ -2,7 +2,7 @@
 
 ;; Copyright (C) 2015-2017  Jorgen Schaefer <contact@jorgenschaefer.de>
 
-;; Version: 1.16
+;; Version: 1.19
 ;; Author: Jorgen Schaefer <contact@jorgenschaefer.de>
 ;; Package-Requires: ((emacs "24.3"))
 ;; URL: https://github.com/jorgenschaefer/emacs-buttercup
@@ -805,10 +805,15 @@ form.")
 DESCRIPTION is a string. BODY is a sequence of instructions,
 mainly calls to `describe', `it' and `before-each'."
   (declare (indent 1) (debug (&define sexp def-body)))
-  (let ((new-body (if (eq (elt body 0) :var)
-                      `((let ,(elt body 1)
-                          ,@(cddr body)))
-                    body)))
+  (let ((new-body
+         (cond
+          ((eq (elt body 0) :var)
+           `((let ,(elt body 1)
+               ,@(cddr body))))
+          ((eq (elt body 0) :var*)
+           `((let* ,(elt body 1)
+               ,@(cddr body))))
+          (t body))))
     `(buttercup-describe ,description (lambda () ,@new-body))))
 
 (defun buttercup-describe (description body-function)
@@ -1652,6 +1657,7 @@ function is disabled to suppress display of all warning messages.
 The contents of this buffer are then displayed after the test
 finishes."
   (when (and (null buffer-name)
+             buttercup-warning-buffer-name
              (get-buffer buttercup-warning-buffer-name))
     (setq buffer-name buttercup-warning-buffer-name))
   (if (equal buffer-name buttercup-warning-buffer-name)
@@ -1672,6 +1678,18 @@ finishes."
     (white   . 37))
   "List of text colors.")
 
+(defmacro buttercup-suppress-warning-capture (&rest body)
+  "Suppress Buttercup's warning capturing within BODY.
+
+Buttercup normally captures all warnings while a test is running
+so it can defer displaying them until after the test is complete.
+However, if you want to catch any warnings yourself as part of
+the test, you need to wrap your code in this macro to suppress
+the capturing behavior."
+  (declare (indent 0))
+  `(let ((buttercup-warning-buffer-name nil))
+     ,@body))
+
 (defun buttercup-colorize (string color)
   "Format STRING with COLOR."
   (let ((color-code (cdr (assoc color buttercup-colors))))
