@@ -379,7 +379,12 @@
     (expect (macroexpand '(describe "description" :var (foo bar) (+ foo bar)))
             :to-equal
             '(buttercup-describe "description"
-                                 (lambda () (let (foo bar) (+ foo bar)))))))
+                                 (lambda () (let (foo bar) (+ foo bar))))))
+  (it "should support the :var* argument"
+    (expect (macroexpand '(describe "description" :var* (foo bar) (+ foo bar)))
+            :to-equal
+            '(buttercup-describe "description"
+                                 (lambda () (let* (foo bar) (+ foo bar)))))))
 
 (describe "The `buttercup-describe' function"
   (it "should run the enclosing body"
@@ -608,16 +613,27 @@
 ;;; Spies
 
 (describe "The Spy "
-  (let (test-function)
+  (let (saved-test-function saved-test-command)
     ;; We use `before-all' here because some tests need to access the
     ;; same function as previous tests in order to work, so overriding
     ;; the function before each test would invalidate those tests.
     (before-all
+      (setq saved-test-function (and (fboundp 'test-function)
+                                     (symbol-function 'test-function))
+            saved-test-command (and (fboundp 'test-command)
+                                    (symbol-function 'test-command)))
       (fset 'test-function (lambda (a b)
                              (+ a b)))
       (fset 'test-command (lambda ()
                             (interactive)
                             t)))
+    (after-all
+      (if saved-test-function
+          (fset 'test-function saved-test-function)
+        (fmakunbound 'test-function))
+      (if saved-test-command
+          (fset 'test-command saved-test-command)
+        (fmakunbound 'test-command)))
 
     (describe "`spy-on' function"
       (it "replaces a symbol's function slot"
@@ -951,7 +967,11 @@
 
       (it "should print the elapsed time for all specs"
         (dolist (state '(pending failed passed))
-          (setq spec (make-buttercup-spec :description "spec" :status state :parent child-suite))
+          (spy-calls-reset 'buttercup--print)
+          (setq spec (make-buttercup-spec :description "spec"
+                                          :parent child-suite
+                                          :status state
+                                          :failure-description ""))
           (buttercup--set-start-time spec)
           (buttercup--set-end-time spec)
           (let ((buttercup-reporter-batch--failures nil))
@@ -960,7 +980,7 @@
           (expect (mapconcat (apply-partially #'apply #'format)
                              (spy-calls-all-args 'buttercup--print)
                              "")
-                  :to-match "([0-9]+\\.[0-9]+\\(h\\|m\\|m?s\\))"))))
+                  :to-match " ([0-9]+\\(\\.[0-9]+\\)?\\(h\\|m\\|m?s\\))\n$"))))
 
     (describe "on the suite-done event"
       (it "should emit a newline at the end of the top-level suite"
@@ -991,36 +1011,41 @@
                 :to-throw)))))
 
 (describe "The `buttercup-run' function"
-  :var (buttercup-suites parent-suite child-suite spec)
-  (cl-flet (((reporter (event arg) (ignore event arg))))
-    (before-each
-      (setq parent-suite (make-buttercup-suite :description "parent-suite")
-            child-suite (make-buttercup-suite :description "child-suite")
-            spec (make-buttercup-spec :description "spec")
-            buttercup-suites (list parent-suite))
-      (buttercup-suite-add-child parent-suite child-suite)
-      (buttercup-suite-add-child child-suite spec)
-      (spy-on 'reporter))
-    (it "should raise an error if at least one spec failed"
-      (setf (buttercup-spec-status spec) 'failed)
-      (cl-letf (((symbol-function 'buttercup--run-suite) #'ignore)
-                (buttercup-reporter 'reporter))
-        (expect (buttercup-run) :to-throw)))
-    (it "should call the reporter twice with events buttercup-started and -done"
-      (cl-letf (((symbol-function 'buttercup--run-suite) #'ignore)
-                (buttercup-reporter 'reporter))
+  :var (parent-suite child-suite spec reporter)
+  (before-each
+    (ignore reporter)
+    (setf (symbol-function 'reporter) (lambda (event arg) (ignore event arg)))
+    (setq parent-suite (make-buttercup-suite :description "parent-suite")
+          child-suite (make-buttercup-suite :description "child-suite")
+          spec (make-buttercup-spec :description "spec"))
+    (buttercup-suite-add-child parent-suite child-suite)
+    (buttercup-suite-add-child child-suite spec)
+    (spy-on 'reporter))
+  (it "should raise an error if at least one spec failed"
+    (setf (buttercup-spec-status spec) 'failed)
+    (cl-letf (((symbol-function 'buttercup--run-suite) #'ignore)
+              (buttercup-reporter 'reporter))
+      (let ((buttercup-suites (list parent-suite)))
+        (expect (buttercup-run) :to-throw))))
+  (it "should call the reporter twice with events buttercup-started and -done"
+    (cl-letf (((symbol-function 'buttercup--run-suite) #'ignore)
+              (buttercup-reporter 'reporter))
+      (let ((buttercup-suites (list parent-suite)))
         (expect (buttercup-run) :not :to-throw)
         (expect 'reporter :to-have-been-called-times 2)
         (expect 'reporter :to-have-been-called-with 'buttercup-started buttercup-suites)
         (expect 'reporter :to-have-been-called-with 'buttercup-done buttercup-suites)))
-    (it "should call `buttercup--run-suite once per suite"
-      (cl-flet (((runner (suite) (ignore suite))))
-        (spy-on 'runner)
-        (cl-letf (((symbol-function 'buttercup--run-suite) #'runner)
-                  (buttercup-reporter 'reporter)
-                  (buttercup-suites (make-list 5 parent-suite)))
-          (expect (buttercup-run) :not :to-throw)
-          (expect 'runner :to-have-been-called-times 5))))))
+    )
+  (it "should call `buttercup--run-suite once per suite"
+    (let ((buttercup-suites (list parent-suite)) runner)
+      (ignore runner)
+      (setf (symbol-function 'runner) (lambda (suite) (ignore suite)))
+      (spy-on 'runner)
+      (cl-letf (((symbol-function 'buttercup--run-suite) #'runner)
+                (buttercup-reporter 'reporter)
+                (buttercup-suites (make-list 5 parent-suite)))
+        (expect (buttercup-run) :not :to-throw)
+        (expect 'runner :to-have-been-called-times 5)))))
 
 (describe "The `buttercup--print' function"
   (before-each
